==> dwarfg_install_1.1.0.tgz: dwarfg_install/appdir/web/gui/src/Entity/MonitoringGroup/MonitoringGroupMapping.php <==
<?php

declare(strict_types=1);

namespace App\Entity\MonitoringGroup;

use App\Entity\Device\Device;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'monitoring_group_device_map')]
#[ORM\Entity]
class MonitoringGroupMapping
{

    final public const ENTITY_TABLE_NAME = 'monitoring_group_device_map';

    /**
     * @var int|null
     */
    #[ORM\Column(type: 'integer')]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'AUTO')]
    private ?int $id = null;

    /**
     * @var Device
     */
    #[ORM\ManyToOne(targetEntity: Device::class, inversedBy: 'monitoringGroupMappings')]
    #[ORM\JoinColumn(name: 'id_device', referencedColumnName: 'id_device')]
    public Device $device;

    /**
     * @var MonitoringGroup
     */
    #[ORM\ManyToOne(targetEntity: MonitoringGroup::class, inversedBy: 'monitoringGroupMappings')]
    #[ORM\JoinColumn(name: 'mongrp_id', referencedColumnName: 'id')]
    public MonitoringGroup $monitoringGroup;

    /**
     * @return int|null
     */
    public function getId(): ?int {

        return $this->id;

    }

    /**
     * @return Device
     */
    public function getDevice(): Device {

        return $this->device;

    }

    public function setDevice(Device $device){

        $this->device = $device;

    }

    /**
     * @return MonitoringGroup
     */
    public function getMonitoringGroup(): MonitoringGroup {

        return $this->monitoringGroup;

    }

    public function setMonitoringGroup(MonitoringGroup $monitoringGroup){

        $this->monitoringGroup = $monitoringGroup;

    }

}

==> dwarfg_install_1.3.0.tgz: dwarfg_install/appdir/web/gui/src/Entity/MonitoringGroup/MonitoringGroupMapping.php <==
<?php

declare(strict_types=1);

namespace App\Entity\MonitoringGroup;

use App\Entity\Device\Device;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'monitoring_group_device_map')]
#[ORM\Entity]
class MonitoringGroupMapping
{

    final public const ENTITY_TABLE_NAME = 'monitoring_group_device_map';

    /**
     * @var int|null
     */
    #[ORM\Column(type: Types::INTEGER)]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'AUTO')]
    private ?int $id = null;

    /**
     * @var Device
     */
    #[ORM\ManyToOne(targetEntity: Device::class, inversedBy: 'monitoringGroupMappings')]
    #[ORM\JoinColumn(name: 'id_device', referencedColumnName: 'id_device')]
    public Device $device;

    /**
     * @var MonitoringGroup
     */
    #[ORM\ManyToOne(targetEntity: MonitoringGroup::class, inversedBy: 'monitoringGroupMappings')]
    #[ORM\JoinColumn(name: 'mongrp_id', referencedColumnName: 'id')]
    public MonitoringGroup $monitoringGroup;

    /**
     * @return int|null
     */
    public function getId(): ?int {

        return $this->id;

    }

    /**
     * @return Device
     */
    public function getDevice(): Device {

        return $this->device;

    }

    public function setDevice(Device $device): void
	{

        $this->device = $device;

    }

    /**
     * @return MonitoringGroup
     */
    public function getMonitoringGroup(): MonitoringGroup {

        return $this->monitoringGroup;

    }

    public function setMonitoringGroup(MonitoringGroup $monitoringGroup): void
	{

        $this->monitoringGroup = $monitoringGroup;

    }

}
